@@ -26,8 +26,8 @@ if pkgutil.find_loader("networkx"):
 else:
     logging.error("networkx is not available. This can lead some features of PM4Py to not work correctly!")
 
-__version__ = '1.3.2'
-__doc__ = "Process Mining for Python"
+__version__ = '1.3.5'
+__doc__ = "Process Mining for Python (PM4Py)"
 __author__ = 'Fraunhofer Institute for Applied Technology'
 __author_email__ = 'pm4py@fit.fraunhofer.de'
 __maintainer__ = 'Fraunhofer Institute for Applied Technology'
