@@ -1,13 +1,16 @@
+import deprecation
+
 from pm4py import util as pmutil
 from pm4py.algo.discovery.transition_system.versions import view_based
-from pm4py.objects.conversion.log import factory as log_conversion
+from pm4py.objects.conversion.log import converter as log_conversion
 from pm4py.util import xes_constants as xes_util
 
 VIEW_BASED = "view_based"
 
 VERSIONS = {VIEW_BASED: view_based.apply}
 
-
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Use algorithm entrypoint instead')
 def apply(log, parameters=None, variant=VIEW_BASED):
     """
     Find transition system given log
