@@ -1,5 +1,7 @@
 import os
 import pandas as pd
+import deprecation
+
 from pm4py.util import constants
 from pm4py.util import xes_constants as xes
 
@@ -35,6 +37,8 @@ except:
 COLUMNS = "columns"
 
 
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Please import the parquet to a pandas df, then convert it to an event log, if needed')
 def apply(path, parameters=None, variant=DEFAULT_VARIANT):
     """
     Import a Parquet file
@@ -75,6 +79,8 @@ def apply(path, parameters=None, variant=DEFAULT_VARIANT):
     return df
 
 
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Please import the parquet to a pandas df, then convert it to an event log, if needed')
 def import_log(path, parameters=None, variant=DEFAULT_VARIANT_LOG):
     """
     Import a Parquet file
@@ -100,6 +106,8 @@ def import_log(path, parameters=None, variant=DEFAULT_VARIANT_LOG):
     return VERSIONS_LOG[variant](path, parameters=parameters)
 
 
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Please import the parquet to a pandas df, then convert it to an event log, if needed')
 def import_minimal_log(path, parameters=None, variant=DEFAULT_VARIANT_LOG):
     """
     Import a Parquet file (as a minimal log with only the essential columns)
@@ -127,6 +135,8 @@ def import_minimal_log(path, parameters=None, variant=DEFAULT_VARIANT_LOG):
     return VERSIONS_LOG[variant](path, parameters=parameters)
 
 
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Please import the parquet to a pandas df, then convert it to an event log, if needed')
 def import_df(path, parameters=None, variant=DEFAULT_VARIANT):
     """
     Import a Parquet file
@@ -149,6 +159,8 @@ def import_df(path, parameters=None, variant=DEFAULT_VARIANT):
     return apply(path, variant=variant, parameters=parameters)
 
 
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Please import the parquet to a pandas df, then convert it to an event log, if needed')
 def get_list_parquet(path, parameters=None):
     """
     Gets the list of Parquets contained into a dataset
