@@ -1,2 +1,2 @@
 from pm4py.visualization import common, dfg, petrinet, process_tree, graphs, sna, transition_system, heuristics_net, \
-    decisiontree, align_table
+    decisiontree, align_table, footprints
