@@ -1,3 +1,5 @@
+import deprecation
+
 from pm4py.visualization.align_table.versions import classic
 from pm4py.visualization.common import gview
 from pm4py.visualization.common import save as gsave
@@ -6,7 +8,8 @@ CLASSIC = "classic"
 
 VERSIONS = {CLASSIC: classic.apply}
 
-
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Use visualizer module instead.')
 def apply(log, aligned_traces, variant=CLASSIC, parameters=None):
     """
     Gets the alignment table visualization from the alignments output
@@ -29,7 +32,8 @@ def apply(log, aligned_traces, variant=CLASSIC, parameters=None):
     """
     return VERSIONS[variant](log, aligned_traces, parameters=parameters)
 
-
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Use visualizer module instead.')
 def save(gviz, output_file_path):
     """
     Save the diagram
@@ -43,7 +47,8 @@ def save(gviz, output_file_path):
     """
     gsave.save(gviz, output_file_path)
 
-
+@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
+                        details='Use visualizer module instead.')
 def view(gviz):
     """
     View the diagram
